Crate oxvg_collections

Crate oxvg_collections 

Collections of data and types for SVG

As opposed to oxvg_ast, which is for the structural types of an SVG document, oxvg_collections is for the data types of an SVG document.

Types

Atom

The atom::Atom is used for storing string representations that may be provided by the parser. It may be used in the values, names, and text-content of a document.

Names

A name::QualName consists of a name::Prefix with an associated name::NS and a local-name represented by an atom::Atom.

The names can be used for the name of an attribute::AttrId or element::ElementId.

Attributes

An attribute::Attr is a data point that can be assigned to an element::ElementId. Attributes described in the SVG have an associated content_type::ContentType.

Elements

An element::ElementId can be thought of as a class of an SVG document with associated attributes and child elements. SVG elements are specified to only allow specific attributes and elements for each element type.

Modules

atom
String type for parsed values
attribute
Types of data which can be assigned to an element’s attributes
content_type
Container for all the possible content that can be used by an attribute
element
Data that can be assigned to an element node.
name
Types for names of elements and attributes

Macros

enum_attr
Creates an attribute type that consists of enumerable idents
is_prefix
Returns whether the prefix matches the given names