pub enum BaselineShift {
Baseline,
Sub,
Super,
Top,
Center,
Bottom,
Percentage(Percentage),
Length(LengthValue),
}Expand description
The baseline-shift attribute allows repositioning of the dominant-baseline relative to the dominant-baseline of the parent text content element.
Variants
Baseline
A length value raises (positive value) or lowers (negative value) the dominant-baseline of the parent text content element by the specified length.
A percentage value raises (positive value) or lowers (negative value) the dominant-baseline of the parent text content element by the specified percentage of the line-height.
Sub
The dominant-baseline is shifted to the default position for subscripts.
Super
The dominant-baseline is shifted to the default position for superscripts.
Top
Align the top edge if the inline box with the top edge of the parent box
Center
Align the centre if the inline box with the centre of the parent box
Bottom
Align the bottom edge if the inline box with the bottom edge of the parent box
Percentage(Percentage)
Raise or lower by a percentage relative to the line-height
Length(LengthValue)
Raise or lower by a specified length