pub enum PointerEvents {
Auto,
BoundingBox,
VisiblePainted,
VisibleFill,
VisibleStroke,
Visible,
Painted,
Fill,
Stroke,
All,
None,
}Expand description
Controls when the element can be the target of pointer events.
Variants
Auto
The default behaviour, identical to "visiblePainted".
BoundingBox
Only triggered when the element is visible and the pointer is over the bounding box of the element
VisiblePainted
Only triggered when the element is visible and the pointer is on a painted area
VisibleFill
Only triggered when the element is visible and the pointer is on the interior (fill) area
VisibleStroke
Only triggered when the element is visible and the pointer is on the perimiter (stroke) area
Visible
Only triggered when the element is visible and the pointer is on the fill/stroke
Painted
Only triggered when the pointer is on a painted area
Fill
Only triggered when the pointer is on the interior (fill) area
Stroke
Only triggered when the pointer is on the perimiter (stroke) area
All
Triggered when the pointer is on the fill/stroke
None
Never triggers