pub enum TextPathSpacing {
Auto,
Exact,
}Expand description
Indicates how the user agent should determine the spacing between typographic characters.
Variants
Auto
Indicates that the user agent should use text-on-a-path layout algorithms
Exact
indicates that the typographic characters should be rendered exactly according to the spacing rules as specified in Text on a path layout rules.